Crate chromiumoxide_fetcher

Crate chromiumoxide_fetcher 

A library for downloading and installing chromium and chrome for testing.

You can either use the tags or a specific revision. The version you download must be at least as recent as the current CDP revision otherwise chromiumoxide will likely not be able to communicate with it.

We provide good defaults for the most common use cases.

Example

use chromiumoxide_fetcher::{BrowserFetcher, BrowserFetcherOptions};

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
    let fetcher = BrowserFetcher::new(BrowserFetcherOptions::default()?);
    let revision_info = fetcher.fetch().await?;
    Ok(())
}

Structs

BrowserFetcher
A BrowserFetcher used to download and install a version of chromium.
BrowserFetcherInstallation
Details of an installed version of chromium
BrowserFetcherOptions
Options for the fetcher
BrowserHost
Host for downloading browsers and metadata.
BuildInfo
Information about a build of a browser.
Revision
A Revision represents a version of chromium.
Version
Represents a version of a browser (e.g. 113.0.5672). The patch

Enums

BrowserKind
The kind of browser to download.
BrowserVersion
Represents a version of a browser.
Channel
The channel of the browser to download.
FetcherError
Platform
List of platforms with pre-built chromium binaries
VersionError