A library for downloading and installing chromium and chrome for testing.
You can either use the tags or a specific revision. The version you download must be at least as recent as the current CDP revision otherwise chromiumoxide will likely not be able to communicate with it.
We provide good defaults for the most common use cases.
Example
use chromiumoxide_fetcher::{BrowserFetcher, BrowserFetcherOptions};
#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
let fetcher = BrowserFetcher::new(BrowserFetcherOptions::default()?);
let revision_info = fetcher.fetch().await?;
Ok(())
}Structs
- Browser
Fetcher - A
BrowserFetcherused to download and install a version of chromium. - Browser
Fetcher Installation - Details of an installed version of chromium
- Browser
Fetcher Options - Options for the fetcher
- Browser
Host - Host for downloading browsers and metadata.
- Build
Info - Information about a build of a browser.
- Revision
- A
Revisionrepresents a version of chromium. - Version
- Represents a version of a browser (e.g. 113.0.5672). The patch
Enums
- Browser
Kind - The kind of browser to download.
- Browser
Version - Represents a version of a browser.
- Channel
- The channel of the browser to download.
- Fetcher
Error - Platform
- List of platforms with pre-built chromium binaries
- Version
Error